@@ -1,6 +1,6 @@
 # Licensed under the GPLv3 - see LICENSE.rst
 """Distributed Acquisition and Data Analysis (DADA) format reader/writer."""
-from .base import open  # noqa
+from .base import open, info, DADAFileNameSequencer  # noqa
 from .header import DADAHeader  # noqa
 from .payload import DADAPayload  # noqa
 from .frame import DADAFrame  # noqa
