@@ -3,6 +3,7 @@ import pickle
 
 import pytest
 import numpy as np
+from numpy.testing import assert_array_equal
 from astropy.time import Time
 import astropy.units as u
 
@@ -1384,6 +1385,108 @@ def test_arochime_vdif():
             pass
 
 
+class TestAROCHIMEPartialCopy:
+    def setup_class(self):
+        self.sample_rate = 800*u.MHz / 1024. / 2.
+
+        with vdif.open(SAMPLE_AROCHIME, 'rs',
+                       sample_rate=self.sample_rate) as fh:
+            self.start_time = fh.start_time
+            self.sample_rate = fh.sample_rate
+            self.stop_time = fh.stop_time
+            self.data = fh.read()
+
+        self.nchan = 128
+        self.channels = slice(0, self.nchan)
+
+    def check_file(self, out_file):
+        with vdif.open(out_file, 'rs', sample_rate=self.sample_rate) as fr:
+            assert fr.start_time == self.start_time
+            assert fr.sample_rate == self.sample_rate
+            assert fr.samples_per_frame == 1
+            assert fr.sample_shape == (2, self.nchan)
+            data = fr.read()
+
+        assert_array_equal(data, self.data[:, :, self.channels])
+
+    def test_via_frames(self, tmpdir):
+        out_file = str(tmpdir.join('upper128_wb.vdif'))
+        with vdif.open(SAMPLE_AROCHIME, 'rb') as fr, \
+             vdif.open(out_file, 'wb') as fw:
+            while True:
+                try:
+                    frame = fr.read_frame()
+                except EOFError:
+                    break
+
+                new_header = frame.header.copy()
+                new_header.nchan = self.nchan
+                new_header.samples_per_frame = 1
+                new_data = frame[:, self.channels]
+                fw.write_frame(new_data, new_header)
+
+        self.check_file(out_file)
+
+    def test_via_frame_sets(self, tmpdir):
+        out_file = str(tmpdir.join('upper128_wb.vdif'))
+        with vdif.open(SAMPLE_AROCHIME, 'rb') as fr, \
+             vdif.open(out_file, 'wb') as fw:
+            while True:
+                try:
+                    frame_set = fr.read_frameset()
+                except EOFError:
+                    break
+
+                new_header = frame_set.header0.copy()
+                new_header.nchan = self.nchan
+                new_header.samples_per_frame = 1
+                new_data = frame_set[:, :, self.channels]
+                fw.write_frameset(new_data, new_header,
+                                  nthread=new_data.shape[1])
+
+        self.check_file(out_file)
+
+    def test_via_stream_reader(self, tmpdir):
+        """Check we can easily copy part of the band."""
+        out_file = str(tmpdir.join('upper128_ws.vdif'))
+        with vdif.open(SAMPLE_AROCHIME, 'rs', sample_rate=self.sample_rate,
+                       subset=(slice(None), self.channels)) as fh:
+            data1 = fh.read()
+            assert data1.shape == (5, 2, self.nchan)
+            assert_array_equal(data1, self.data[:, :, self.channels])
+            out_header = fh.header0.copy()
+            out_header.nchan = self.nchan
+            out_header.samples_per_frame = 1
+            with vdif.open(out_file, 'ws', sample_rate=self.sample_rate,
+                           header0=out_header, nthread=2) as fw:
+                assert fw.start_time == self.start_time
+                assert fw.sample_rate == self.sample_rate
+                assert fw.samples_per_frame == 1
+                assert fw.sample_shape == (2, 128)
+                fw.write(data1)
+                assert fw.tell() == fh.tell()
+                assert fw.time == fh.time
+
+        self.check_file(out_file)
+
+    def test_via_binary_modification(self, tmpdir):
+        out_file = str(tmpdir.join('upper128_binary_mod.vdif'))
+        # 1024 bytes payload + 32 bytes header = 1056 bytes = 264 words
+        binary = np.fromfile(SAMPLE_AROCHIME, '<u4').reshape(-1, 264)
+        header0 = vdif.VDIFHeader(binary[0, :8])
+        header0.nchan = 128
+        header0.samples_per_frame = 1
+        assert header0.words[2] == (
+            (32+128) // 8  # frame (header+payload) length in 8-byte words
+            + (7 << 24)    # lg2nchan
+            + (1 << 29))   # VDIF version number
+        binary[:, 2] = header0.words[2]
+        # Only save header (8 words) plus first 128 channels = 32 words.
+        binary[:, :40].tofile(out_file)
+
+        self.check_file(out_file)
+
+
 def test_count_not_changed():
     """Test that count input to .read() does not get changed."""
     # Regression test for problem reported in
@@ -1560,3 +1663,20 @@ def test_edf3_vdif_payload_size(tmpdir):
         assert header2.payload_nbytes == 1000
         assert header2.samples_per_frame == 4000
         assert np.all(data2 == data1)
+
+
+def test_one_frame_per_second(tmpdir):
+    testfile = str(tmpdir.join('test.vdif'))
+    with vdif.open(SAMPLE_FILE, 'rs') as fh:
+        header1 = fh.header0.copy()
+        header1.frame_rate = 1 * u.Hz
+        data1 = fh.read()
+        with vdif.open(testfile, 'ws', header0=header1, nthread=8) as fw:
+            fw.write(data1)
+            stop_time = fw.time
+
+    with vdif.open(testfile, 'rs') as fc:
+        assert fc._frame_rate == 1 * u.Hz
+        assert abs(fc.stop_time - stop_time) < 1 * u.ns
+        data2 = fc.read()
+        assert np.all(data2 == data1)
